@@ -10,6 +10,7 @@ my $wait = .75;
 $wait = $joined =~ /(\d++)/ if (scalar(@ARGV));
 my $dump = 0;
 $dump = 1 if ($joined =~ /dump/i);
+$wait = 0 if ($joined =~ /wait/i);
 
 my $fb = Graphics::Framebuffer->new('SPLASH' => 1,'SHOW_ERRORS'=>1); # ,'SIMULATED_X'=>1280,'SIMULATED_Y'=>720);
 
@@ -47,7 +48,11 @@ foreach my $font (sort(keys %{$fb->{'FONTS'}})) {
         $fb->ttf_print(
             $fb->ttf_print($smprint)
         );
-        sleep $wait;
+        if ($wait) {
+            sleep $wait;
+        } else {
+            <>;
+        }
     } else {
         print STDOUT "$font\n";
     }
